@@ -18,7 +18,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "Combiner.h"
+
 #include "Config.h"
+#include "IColor.h"
+#include "RSP_Parser.h"
 #include "RenderBase.h"
 
 //static BOOL g_bHiliteRGBAHack = FALSE;
@@ -411,13 +414,6 @@ void CColorCombiner::UpdateCombiner(uint32 dwMux0, uint32 dwMux1)
 
             m_decodedMux.Hack();
 
-            if( !m_bSupportMultiTexture )
-            {
-                m_decodedMux.ReplaceVal(MUX_TEXEL1, MUX_TEXEL0);
-                m_decodedMux.ReplaceVal(MUX_LODFRAC,1);
-                m_decodedMux.ReplaceVal(MUX_PRIMLODFRAC,1);
-            }
-
             m_decodedMux.Simplify();
             if( m_supportedStages>1)    
                 m_decodedMux.SplitComplexStages();
