@@ -19,6 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define M64P_PLUGIN_PROTOTYPES 1
 #include "m64p_plugin.h"
+#include "osal_preproc.h"
 #include "typedefs.h"
 
 #ifndef DEBUGGER
@@ -248,15 +249,8 @@ void DumpTexture(int tex, TextureChannel channel = TXT_RGB )
 
 void DumpRenderTexture(int tex=-1)
 {
-    if( CDeviceBuilder::GetBuilder()->GetGeneralDeviceType() == DIRECTX_DEVICE )
-    {
-        g_pFrameBufferManager->DisplayRenderTexture(tex);
-    }
-    else
-    {
-        debuggerDrawRenderTextureNo = tex;
-        debuggerDrawRenderTexture = true;
-    }
+    debuggerDrawRenderTextureNo = tex;
+    debuggerDrawRenderTexture = true;
 }
 
 void DumpTextureToFile(int tex, TextureChannel channel = TXT_RGB)
