@@ -19,14 +19,22 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 // ===========================================================================
 
+#include <string.h>
+#include <algorithm>
 #include <vector>
 
+#include "Config.h"
 #include "ConvertImage.h"
+#include "Debugger.h"
 #include "DeviceBuilder.h"
 #include "FrameBuffer.h"
-#include "UcodeDefs.h"
+#include "GraphicsContext.h"
 #include "RSP_Parser.h"
 #include "Render.h"
+#include "RenderBase.h"
+#include "UcodeDefs.h"
+#include "Video.h"
+#include "m64p_plugin.h"
 
 extern TMEMLoadMapInfo g_tmemLoadAddrMap[0x200];    // Totally 4KB TMEM;
 
@@ -484,8 +492,8 @@ void TexRectToFrameBuffer_8b(uint32 dwXL, uint32 dwYL, uint32 dwXH, uint32 dwYH,
     uint32 dwLeft = dwXL;
     uint32 dwTop = dwYL;
 
-    dwWidth = min(dwWidth, maxW-dwLeft);
-    dwHeight = min(dwHeight, maxH-dwTop);
+    dwWidth = std::min(dwWidth, maxW-dwLeft);
+    dwHeight = std::min(dwHeight, maxH-dwTop);
     
     if( maxH <= dwTop )
         return;
@@ -541,8 +549,8 @@ void TexRectToN64FrameBuffer_16b(uint32 x0, uint32 y0, uint32 width, uint32 heig
 
 #define FAST_CRC_CHECKING_INC_X 13
 #define FAST_CRC_CHECKING_INC_Y 11
-#define FAST_CRC_MIN_Y_INC      2
-#define FAST_CRC_MIN_X_INC      2
+#define FAST_CRC_MIN_Y_INC      2u
+#define FAST_CRC_MIN_X_INC      2u
 #define FAST_CRC_MAX_X_INC      7
 #define FAST_CRC_MAX_Y_INC      3
 extern uint32 dwAsmHeight;
@@ -562,7 +570,7 @@ uint32 CalculateRDRAMCRC(void *pPhysicalAddress, uint32 left, uint32 top, uint32
         uint32 xinc = realWidthInDWORD / FAST_CRC_CHECKING_INC_X;   
         if( xinc < FAST_CRC_MIN_X_INC )
         {
-            xinc = min(FAST_CRC_MIN_X_INC, width);
+            xinc = std::min(FAST_CRC_MIN_X_INC, width);
         }
         if( xinc > FAST_CRC_MAX_X_INC )
         {
@@ -572,7 +580,7 @@ uint32 CalculateRDRAMCRC(void *pPhysicalAddress, uint32 left, uint32 top, uint32
         uint32 yinc = height / FAST_CRC_CHECKING_INC_Y; 
         if( yinc < FAST_CRC_MIN_Y_INC ) 
         {
-            yinc = min(FAST_CRC_MIN_Y_INC, height);
+            yinc = std::min(FAST_CRC_MIN_Y_INC, height);
         }
         if( yinc > FAST_CRC_MAX_Y_INC )
         {
@@ -1664,16 +1672,6 @@ void FrameBufferManager::ActiveTextureBuffer(void)
             //  CRender::GetRender()->LoadTxtrBufFromRDRAM();
             //}
         }
-        else
-        {
-            if( CDeviceBuilder::m_deviceGeneralType == DIRECTX_DEVICE )
-            {
-                TRACE1("Error to set Render Target: %d", idxToUse);
-                TRACE1("Addr = %08X", gRenderTextureInfos[idxToUse].CI_Info.dwAddr);
-                TRACE2("Width = %d, Height=%d", gRenderTextureInfos[idxToUse].N64Width, gRenderTextureInfos[idxToUse].N64Height);
-            }
-        }   
-
 
         TXTRBUF_DUMP(TRACE2("Rendering to render_texture %d, addr=%08X", idxToUse, g_CI.dwAddr));
         DEBUGGER_PAUSE_AND_DUMP_NO_UPDATE(NEXT_RENDER_TEXTURE, 
