@@ -19,14 +19,22 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#include "osal_opengl.h"
+#include <stddef.h>
 
+#include "CombinerDefs.h"
+#include "DecodedMux.h"
+#include "GraphicsContext.h"
 #include "OGLCombiner.h"
 #include "OGLDebug.h"
-#include "OGLRender.h"
-#include "OGLGraphicsContext.h"
 #include "OGLDecodedMux.h"
+#include "OGLGraphicsContext.h"
+#include "OGLRender.h"
 #include "OGLTexture.h"
+#include "RenderBase.h"
+#include "osal_opengl.h"
+#include "osal_preproc.h"
+
+class CRender;
 
 //========================================================================
 uint32 DirectX_OGL_BlendFuncMaps [] =
@@ -69,7 +77,6 @@ bool COGLColorCombiner::Initialize(void)
     m_bSupportAdd = false;
     m_bSupportSubtract = false;
     m_supportedStages = 1;
-    m_bSupportMultiTexture = false;
 
     COGLGraphicsContext *pcontext = (COGLGraphicsContext *)(CGraphicsContext::g_pGraphicsContext);
     if( pcontext->IsExtensionSupported(OSAL_GL_ARB_TEXTURE_ENV_ADD) || pcontext->IsExtensionSupported("GL_EXT_texture_env_add") )
@@ -158,7 +165,7 @@ void COGLColorCombiner::InitCombinerCycle12(void)
         return;
     }
 
-#if SDL_VIDEO_OPENGL
+#ifndef USE_GLES
     uint32 mask = 0x1f;
     COGLTexture* pTexture = g_textures[gRSP.curTile].m_pCOGLTexture;
     if( pTexture )
@@ -211,7 +218,7 @@ void COGLColorCombiner::InitCombinerCycle12(void)
             if( shadeIsUsedInColor && texIsUsedInColor )
             {
                 if( m_bSupportSubtract )
-                    glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_SUBTRACT_ARB);
+                    glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_SUBTRACT);
                 else
                     glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_BLEND);
             }
