@@ -16,6 +16,9 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
+#include <algorithm>
+
+#include "CombinerDefs.h"
 #include "OGLDecodedMux.h"
 
 //========================================================================
@@ -27,7 +30,7 @@ void COGLDecodedMux::Simplify(void)
 void COGLDecodedMux::Reformat(void)
 {
     DecodedMux::Reformat();
-    mType = max(max(max(splitType[0], splitType[1]),splitType[2]),splitType[3]);
+    mType = std::max(std::max(std::max(splitType[0], splitType[1]),splitType[2]),splitType[3]);
 }
 
 void COGLExtDecodedMux::Simplify(void)
@@ -97,21 +100,3 @@ void COGLExtDecodedMux::FurtherFormatForOGL2(void)
     */
 }
 
-
-void COGLExtDecodedMuxTNT2::FurtherFormatForOGL2(void)
-{
-    if( Count(MUX_PRIM) >= Count(MUX_ENV) )
-    {
-        //ReplaceVal(MUX_ENV, MUX_PRIM);
-        //ReplaceVal(MUX_ENV, MUX_SHADE);
-        ReplaceVal(MUX_ENV, MUX_1);
-        //ReplaceVal(MUX_PRIM, MUX_0);
-    }
-    else
-    {
-        //ReplaceVal(MUX_PRIM, MUX_ENV);
-        //ReplaceVal(MUX_PRIM, MUX_SHADE);
-        ReplaceVal(MUX_PRIM, MUX_0);
-    }
-}
-
