@@ -21,10 +21,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <vector>
 
-#include "osal_opengl.h"
-
-#include "OGLCombiner.h"
 #include "GeneralCombiner.h"
+#include "OGLCombiner.h"
+#include "osal_opengl.h"
+#include "typedefs.h"
+
+class CRender;
 
 typedef union 
 {
@@ -133,7 +135,6 @@ protected:
     COGLColorCombiner4(CRender *pRender);
     ~COGLColorCombiner4() {};
 
-    bool m_bOGLExtCombinerSupported;        // Is this OGL extension combiner supported by the video card driver?
     bool m_bSupportModAdd_ATI;
     bool m_bSupportModSub_ATI;
     GLint m_maxTexUnits;
@@ -161,61 +162,5 @@ private:
     virtual GLint MapAlphaArgs(uint8 arg);
 };
 
-
-class COGLColorCombiner4v2 : public COGLColorCombiner4
-{
-    /************************************************************************
-     * Version 2 of OGL 1.4 combiner
-     * Will support up to 4 texture units
-     * Texture unit 0 and 1 are for N64 texture T0 and T1
-     * Texture unit 2 and 3 will be used to map constant colors
-     * Constant color mapping:
-     *    OGL constant factor:      MUX_PRIM
-     *    ARB_TEXTURE2:             MUX_ENV
-     *    ARB_TEXTURE3:             MUX_LODFRAC
-     ************************************************************************/
-protected:
-    friend class OGLDeviceBuilder;
-    virtual void GenerateCombinerSettingConstants(int index);
-    virtual int SaveParsedResult(OGLExtCombinerSaveType &result);
-
-    COGLColorCombiner4v2(CRender *pRender);
-    ~COGLColorCombiner4v2() {};
-
-    static GLint RGBArgsMap4v2[];
-
-private:
-    virtual GLint MapRGBArgs(uint8 arg);
-    virtual GLint MapAlphaArgs(uint8 arg);
-};
-
-//////////////////////////////////////////////////////////////////////////
-// OpenGL 1.2, 1.3 combiner which does not support Texture Crossbar feature
-class COGLColorCombiner2 : public COGLColorCombiner4, CGeneralCombiner
-{
-public:
-    bool Initialize(void);
-
-#ifdef DEBUGGER
-    void DisplaySimpleMuxString(void);
-#endif
-
-protected:
-    friend class OGLDeviceBuilder;
-
-    COGLColorCombiner2(CRender *pRender);
-    ~COGLColorCombiner2() {};
-
-private:
-    virtual int ParseDecodedMux();
-    virtual void GenerateCombinerSetting(int index);
-    virtual void GenerateCombinerSettingConstants(int index);
-
-    virtual GLint MapRGBArgs(uint8 arg);
-    virtual GLint MapAlphaArgs(uint8 arg);
-    static GLint RGBArgsMap2[];
-};
-
-
 #endif
 
