@@ -20,6 +20,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define _OGL_EXT_RENDER_H_
 
 #include "OGLRender.h"
+#include "osal_opengl.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
 
 class COGLExtRender : public OGLRender
 {
