@@ -19,8 +19,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef _OGL_CONTEXT_H_
 #define _OGL_CONTEXT_H_
 
-#include "typedefs.h"
 #include "GraphicsContext.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
 
 class COGLGraphicsContext : public CGraphicsContext
 {
@@ -38,7 +39,6 @@ public:
     int ToggleFullscreen();     // return 0 as the result is windowed
 
     bool IsExtensionSupported(const char* pExtName);
-    bool IsWglExtensionSupported(const char* pExtName);
     static void InitDeviceParameters();
 
     //Get methods (TODO, remove all friend class and use get methods instead)
@@ -53,37 +53,14 @@ protected:
     bool SetFullscreenMode();
     bool SetWindowMode();
 
-    // Important OGL extension features
-    bool    m_bSupportMultiTexture;
-    bool    m_bSupportTextureEnvCombine;
-    bool    m_bSupportSeparateSpecularColor;
-    bool    m_bSupportSecondColor;
-    bool    m_bSupportFogCoord;
-    bool    m_bSupportTextureObject;
-
     // Optional OGL extension features;
-    bool    m_bSupportRescaleNormal;
-    bool    m_bSupportLODBias;
-    bool    m_bSupportAnisotropicFiltering;
-    int     m_maxAnisotropicFiltering;
+    bool m_bSupportAnisotropicFiltering;
+    int  m_maxAnisotropicFiltering;
 
-    // Nvidia OGL only features
-    bool    m_bSupportTextureMirrorRepeat;
-    bool    m_bSupportTextureLOD;
-    bool    m_bSupportNVRegisterCombiner;
-    bool    m_bSupportBlendColor;
-    bool    m_bSupportBlendSubtract;
-    bool    m_bSupportNVTextureEnvCombine4;
-    
-    // Minimal requirements, I will even not check them at runtime
-    //bool  m_bSupportTextureEnvAdd;
-    //bool  m_bSupportVertexArray;
-
-    const unsigned char*    m_pVendorStr;
-    const unsigned char*    m_pRenderStr;
-    const unsigned char*    m_pExtensionStr;
-    const char* m_pWglExtensionStr;
-    const unsigned char*    m_pVersionStr;
+    const unsigned char* m_pVendorStr;
+    const unsigned char* m_pRenderStr;
+    const unsigned char* m_pExtensionStr;
+    const unsigned char* m_pVersionStr;
 };
 
 #endif
