@@ -19,9 +19,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 // Texture related ucode
 
+#include <stdlib.h>
 #include <algorithm>
 
-#include <stdlib.h>
 #include "Render.h"
 
 uint32 g_TmemFlag[16];
@@ -30,7 +30,6 @@ bool IsTmemFlagValid(uint32 tmemAddr);
 uint32 GetValidTmemInfoIndex(uint32 tmemAddr);
 
 void EnhanceTexture(TxtrCacheEntry *pEntry);
-void MirrorTexture(uint32 tileno, TxtrCacheEntry *pEntry);
 void LoadHiresTexture( TxtrCacheEntry &entry );
 
 
@@ -49,9 +48,9 @@ uint32 sizeBytes[4] = {0,1,2,4};
 inline uint32 Txl2Words(uint32 width, uint32 size)
 {
     if( size == TXT_SIZE_4b )
-        return max(1, width/16);
+        return std::max(1u, width/16);
     else
-        return max(1, width*sizeBytes[size]/8);
+        return std::max(1u, width*sizeBytes[size]/8);
 }
 
 inline uint32 CalculateImgSize(uint32 width, uint32 height, uint32 size)
@@ -749,7 +748,7 @@ bool CalculateTileSizes_method_2(int tileno, TMEMLoadMapInfo *info, TxtrInfo &gt
         if( gti.WidthToLoad > gti.HeightToLoad )
         {
             uint32 newheight = (dwPitch << 1 )>> tile.dwSize;
-            tile.dwWidth = gti.WidthToLoad = gti.WidthToCreate = min(newheight, (gti.WidthToLoad&0xFFFFFFFE));
+            tile.dwWidth = gti.WidthToLoad = gti.WidthToCreate = std::min(newheight, (gti.WidthToLoad&0xFFFFFFFE));
             tile.dwHeight = gti.HeightToCreate = gti.HeightToLoad = ((0x200 - tile.dwTMem) << (4-tile.dwSize)) / gti.WidthToLoad;
         }
         else
@@ -962,30 +961,30 @@ bool CalculateTileSizes_method_1(int tileno, TMEMLoadMapInfo *info, TxtrInfo &gt
 
     if( tile.dwMaskS == 0 || tile.bClampS )
     {
-        gti.WidthToLoad = linewidth ? min( linewidth, maskwidth ? min(clampwidth,maskwidth) : clampwidth ) : clampwidth;
+        gti.WidthToLoad = linewidth ? std::min( linewidth, maskwidth ? std::min(clampwidth,maskwidth) : clampwidth ) : clampwidth;
         if( tile.dwMaskS && clampwidth < maskwidth )
             tile.dwWidth = gti.WidthToCreate = clampwidth;
         else
-            tile.dwWidth = gti.WidthToCreate = max(clampwidth,maskwidth);
+            tile.dwWidth = gti.WidthToCreate = std::max(clampwidth,maskwidth);
     }
     else
     {
-        gti.WidthToLoad = loadwidth > 2 ? min(loadwidth,maskwidth) : maskwidth;
-        if( linewidth ) gti.WidthToLoad = min( linewidth, (int)gti.WidthToLoad );
+        gti.WidthToLoad = loadwidth > 2 ? std::min(loadwidth,maskwidth) : maskwidth;
+        if( linewidth ) gti.WidthToLoad = std::min( linewidth, (int)gti.WidthToLoad );
         tile.dwWidth = gti.WidthToCreate = maskwidth;
     }
 
     if( tile.dwMaskT == 0 || tile.bClampT )
     {
-        gti.HeightToLoad = maskheight ? min(clampheight,maskheight) : clampheight;
+        gti.HeightToLoad = maskheight ? std::min(clampheight,maskheight) : clampheight;
         if( tile.dwMaskT && clampheight < maskheight )
             tile.dwHeight = gti.HeightToCreate = clampheight;
         else
-            tile.dwHeight = gti.HeightToCreate = max(clampheight,maskheight);
+            tile.dwHeight = gti.HeightToCreate = std::max(clampheight,maskheight);
     }
     else
     {
-        gti.HeightToLoad = loadheight > 2 ? min(loadheight,maskheight) : maskheight;
+        gti.HeightToLoad = loadheight > 2 ? std::min(loadheight,maskheight) : maskheight;
         tile.dwHeight = gti.HeightToCreate = maskheight;
     }
 
@@ -1006,7 +1005,7 @@ bool CalculateTileSizes_method_1(int tileno, TMEMLoadMapInfo *info, TxtrInfo &gt
         if( gti.WidthToLoad > gti.HeightToLoad )
         {
             uint32 newheight = (tile.dwPitch << 1 )>> tile.dwSize;
-            tile.dwWidth = gti.WidthToLoad = gti.WidthToCreate = min(newheight, (gti.WidthToLoad&0xFFFFFFFE));
+            tile.dwWidth = gti.WidthToLoad = gti.WidthToCreate = std::min(newheight, (gti.WidthToLoad&0xFFFFFFFE));
             tile.dwHeight = gti.HeightToCreate = gti.HeightToLoad = ((0x200 - tile.dwTMem) << (4-tile.dwSize)) / gti.WidthToLoad;
         }
         else
@@ -1159,11 +1158,6 @@ void PrepareTextures()
                             SAFE_DELETE(pEntry->pEnhancedTexture);
                         }
 
-                        if( pEntry->pEnhancedTexture == NULL )
-                        {
-                            MirrorTexture(tilenos[i], pEntry);;
-                        }
-
                         if( options.bLoadHiResTextures && (pEntry->pEnhancedTexture == NULL || pEntry->dwEnhancementFlag < TEXTURE_EXTERNAL ) )
                         {
                             LoadHiresTexture(*pEntry);
@@ -1934,7 +1928,7 @@ void DLParser_TexRect(Gfx *gfx)
         }
     }
 
-    if( status.bHandleN64RenderTexture )    g_pRenderTextureInfo->maxUsedHeight = max(g_pRenderTextureInfo->maxUsedHeight,(int)dwYH);
+    if( status.bHandleN64RenderTexture )    g_pRenderTextureInfo->maxUsedHeight = std::max(g_pRenderTextureInfo->maxUsedHeight,(int)dwYH);
 
     ForceMainTextureIndex(curTile);
 }
@@ -2004,7 +1998,7 @@ void DLParser_TexRectFlip(Gfx *gfx)
     CRender::g_pRender->TexRectFlip(dwXL, dwYL, dwXH, dwYH, t0u0, t0v0, t0u1, t0v1);
     status.dwNumTrisRendered += 2;
 
-    if( status.bHandleN64RenderTexture )    g_pRenderTextureInfo->maxUsedHeight = max(g_pRenderTextureInfo->maxUsedHeight,int(dwYL+(dwXH-dwXL)));
+    if( status.bHandleN64RenderTexture )    g_pRenderTextureInfo->maxUsedHeight = std::max(g_pRenderTextureInfo->maxUsedHeight,int(dwYL+(dwXH-dwXL)));
 
     ForceMainTextureIndex(curTile);
 }
