@@ -899,7 +899,7 @@ void DLParser_RS_Color_Buffer(Gfx *gfx)
         DebuggerAppendMsg("Vtx_Color at PC=%08X: 0x%08x 0x%08x\n", dwPC-8, (gfx->words.w0), (gfx->words.w1));
         if( dwAddr < g_dwRamSize )
         {
-            DumpHex(dwAddr, min(64, g_dwRamSize-dwAddr));
+            DumpHex(dwAddr, std::min(64, g_dwRamSize-dwAddr));
         }
     }
 #endif
@@ -929,7 +929,7 @@ void DLParser_RS_Vtx_Buffer(Gfx *gfx)
         DebuggerAppendMsg("Vtx_XYZ at PC=%08X: 0x%08x 0x%08x\n", dwPC-8, (gfx->words.w0), (gfx->words.w1));
         if( dwAddr < g_dwRamSize )
         {
-            DumpHex(dwAddr, min(64, g_dwRamSize-dwAddr));
+            DumpHex(dwAddr, std::min(64, g_dwRamSize-dwAddr));
         }
     }
 #endif
@@ -1724,7 +1724,7 @@ void DLParser_TexRect_Last_Legion(Gfx *gfx)
     }
 
     if( status.bHandleN64RenderTexture ) 
-        g_pRenderTextureInfo->maxUsedHeight = max(g_pRenderTextureInfo->maxUsedHeight,(int)dwYH);
+        g_pRenderTextureInfo->maxUsedHeight = std::max(g_pRenderTextureInfo->maxUsedHeight,(int)dwYH);
 
     ForceMainTextureIndex(curTile);
 }
