@@ -17,16 +17,30 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <algorithm>
 #include <SDL.h>
-
-#include "ConvertImage.h"
-#include "GraphicsContext.h"
-#include "Render.h"
-#include "RenderTexture.h"
-#include "Video.h"
-#include "ucode.h"
+#include <stdlib.h>
+#include <string.h>
 #include <time.h>
+#include <algorithm>
+
+#include "Config.h"
+#include "ConvertImage.h"
+#include "Debugger.h"
+#include "GraphicsContext.h"
+#include "RSP_Parser.h"
+#include "RSP_S2DEX.h"
+#include "Render.h"
+#include "RenderBase.h"
+#include "RenderTexture.h"
+#include "TextureManager.h"
+#include "Timing.h"
+#include "UcodeDefs.h"
+#include "VectorMath.h"
+#include "Video.h"
+#include "m64p_plugin.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
+#include "ucode.h"
 
 //////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////
@@ -258,13 +272,13 @@ uint16  g_wRDPTlut[0x200];
 uint32  g_dwRDPPalCrc[16];
 
 #include "FrameBuffer.h"
+#include "RDP_Texture.h"
 #include "RSP_GBI0.h"
 #include "RSP_GBI1.h"
 #include "RSP_GBI2.h"
 #include "RSP_GBI2_ext.h"
 #include "RSP_GBI_Others.h"
 #include "RSP_GBI_Sprite2D.h"
-#include "RDP_Texture.h"
 
 //////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////
@@ -1316,12 +1330,12 @@ void DLParser_FillRect(Gfx *gfx)
     {
         if( !status.bCIBufferIsRendered ) g_pFrameBufferManager->ActiveTextureBuffer();
 
-        status.leftRendered = status.leftRendered<0 ? x0 : min((int)x0,status.leftRendered);
-        status.topRendered = status.topRendered<0 ? y0 : min((int)y0,status.topRendered);
-        status.rightRendered = status.rightRendered<0 ? x1 : max((int)x1,status.rightRendered);
-        status.bottomRendered = status.bottomRendered<0 ? y1 : max((int)y1,status.bottomRendered);
+        status.leftRendered = status.leftRendered<0 ? x0 : std::min((int)x0,status.leftRendered);
+        status.topRendered = status.topRendered<0 ? y0 : std::min((int)y0,status.topRendered);
+        status.rightRendered = status.rightRendered<0 ? x1 : std::max((int)x1,status.rightRendered);
+        status.bottomRendered = status.bottomRendered<0 ? y1 : std::max((int)y1,status.bottomRendered);
 
-        g_pRenderTextureInfo->maxUsedHeight = max(g_pRenderTextureInfo->maxUsedHeight,(int)y1);
+        g_pRenderTextureInfo->maxUsedHeight = std::max(g_pRenderTextureInfo->maxUsedHeight,(int)y1);
 
         if( status.bDirectWriteIntoRDRAM || ( x0==0 && y0==0 && (x1 == g_pRenderTextureInfo->N64Width || x1 == g_pRenderTextureInfo->N64Width-1 ) ) )
         {
@@ -1393,10 +1407,10 @@ void DLParser_FillRect(Gfx *gfx)
         {
             if( !status.bCIBufferIsRendered ) g_pFrameBufferManager->ActiveTextureBuffer();
 
-            status.leftRendered = status.leftRendered<0 ? x0 : min((int)x0,status.leftRendered);
-            status.topRendered = status.topRendered<0 ? y0 : min((int)y0,status.topRendered);
-            status.rightRendered = status.rightRendered<0 ? x1 : max((int)x1,status.rightRendered);
-            status.bottomRendered = status.bottomRendered<0 ? y1 : max((int)y1,status.bottomRendered);
+            status.leftRendered = status.leftRendered<0 ? x0 : std::min((int)x0,status.leftRendered);
+            status.topRendered = status.topRendered<0 ? y0 : std::min((int)y0,status.topRendered);
+            status.rightRendered = status.rightRendered<0 ? x1 : std::max((int)x1,status.rightRendered);
+            status.bottomRendered = status.bottomRendered<0 ? y1 : std::max((int)y1,status.bottomRendered);
         }
 
         if( gRDP.otherMode.cycle_type == CYCLE_TYPE_FILL )
