@@ -18,17 +18,27 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #define M64P_PLUGIN_PROTOTYPES 1
-#include "osal_preproc.h"
-#include "m64p_plugin.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <algorithm>
 
+#include "Blender.h"
 #include "ConvertImage.h"
 #include "DeviceBuilder.h"
 #include "FrameBuffer.h"
+#include "GraphicsContext.h"
 #include "Render.h"
-
+#include "RenderTexture.h"
+#include "Texture.h"
+#include "VectorMath.h"
+#include "Video.h"
+#include "liblinux/BMGImage.h"
 #include "liblinux/BMGLibPNG.h"
-
-#include <algorithm>
+#include "liblinux/pngrw.h"
+#include "m64p_plugin.h"
+#include "m64p_types.h"
+#include "osal_preproc.h"
 
 extern FiddledVtx * g_pVtxBase;
 CRender * CRender::g_pRender=NULL;
@@ -42,13 +52,6 @@ extern char* right (const char * src, int nchars);
   #define strcasecmp _stricmp
 #endif
 
-#ifdef min
-#undef min
-#endif
-#ifdef max
-#undef max
-#endif
-
 //========================================================================
 CRender * CRender::GetRender(void)
 {
@@ -214,6 +217,20 @@ void CRender::SetWorldView(const Matrix & mat, bool bPush, bool bReplace)
         {
             // Load projection matrix
             gRSP.modelviewMtxs[gRSP.modelViewMtxTop] = mat;
+
+            // Hack needed to show flashing last heart and map arrows in Zelda OoT & MM
+            // It renders at Z cordinate = 0.0f that gets clipped away
+            // So we translate them a bit along Z to make them stick
+            if( options.enableHackForGames == HACK_FOR_ZELDA || options.enableHackForGames == HACK_FOR_ZELDA_MM) 
+            {
+                if(gRSP.modelviewMtxs[gRSP.modelViewMtxTop]._43 == 0.0f
+                    && gRSP.modelviewMtxs[gRSP.modelViewMtxTop]._42 != 0.0f
+                    && gRSP.modelviewMtxs[gRSP.modelViewMtxTop]._42 <= 94.5f
+                    && gRSP.modelviewMtxs[gRSP.modelViewMtxTop]._42 >= -94.5f)
+                {
+                    gRSP.modelviewMtxs[gRSP.modelViewMtxTop]._43 -= 10.1f;
+                }
+            }
         }
         else
         {
@@ -1085,29 +1102,6 @@ void CRender::SetTextureEnableAndScale(int dwTile, bool bEnable, float fScaleX,
     }
 }
 
-void CRender::SetFogFlagForNegativeW()
-{
-    if( !gRSP.bFogEnabled ) return;
-
-    m_bFogStateSave = gRSP.bFogEnabled;
-
-    bool flag=gRSP.bFogEnabled;
-    
-    for (uint32 i = 0; i < gRSP.numVertices; i++) 
-    {
-        if( g_vtxBuffer[i].rhw < 0 )
-            flag = FALSE;
-    }
-
-    TurnFogOnOff(flag);
-}
-
-void CRender::RestoreFogFlag()
-{
-    if( !gRSP.bFogEnabled ) return;
-    TurnFogOnOff(m_bFogStateSave);
-}
-
 void CRender::SetViewport(int nLeft, int nTop, int nRight, int nBottom, int maxZ)
 {
     if( status.bHandleN64RenderTexture )
