@@ -17,15 +17,28 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#include <string.h>
+#include <algorithm>
 #include <cmath>
 #include <vector>
 
-#include "osal_preproc.h"
-#include "float.h"
+#include "Combiner.h"
+#include "CombinerDefs.h"
+#include "Config.h"
+#include "Debugger.h"
+#include "DecodedMux.h"
 #include "DeviceBuilder.h"
-#include "VertexShaderConstantDef.h"
+#include "IColor.h"
+#include "RSP_Parser.h"
 #include "Render.h"
+#include "RenderBase.h"
 #include "Timing.h"
+#include "VectorMath.h"
+#include "Video.h"
+#include "float.h"
+#include "m64p_plugin.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
 
 extern FiddledVtx * g_pVtxBase;
 
@@ -744,7 +757,7 @@ void SetFogMinMax(float fMin, float fMax, float fMul, float fOffset)
     }
 
     {
-        gRSPfFogMin = max(0,fMin/500-1);
+        gRSPfFogMin = std::max(0.f,fMin/500-1);
         gRSPfFogMax = fMax/500-1;
     }
 
@@ -805,28 +818,20 @@ void TexGen(float &s, float &t)
     }
 }
 
-void ComputeLOD(bool openGL)
+void ComputeLOD()
 {
     TLITVERTEX &v0 = g_vtxBuffer[0];
     TLITVERTEX &v1 = g_vtxBuffer[1];
     RenderTexture &tex0 = g_textures[gRSP.curTile];
 
     float d,dt;
-    if( openGL )
-    {
-        float x = g_vtxProjected5[0][0] / g_vtxProjected5[0][4] - g_vtxProjected5[1][0] / g_vtxProjected5[1][4];
-        float y = g_vtxProjected5[0][1] / g_vtxProjected5[0][4] - g_vtxProjected5[1][1] / g_vtxProjected5[1][4];
 
-        x = windowSetting.vpWidthW*x/windowSetting.fMultX/2;
-        y = windowSetting.vpHeightW*y/windowSetting.fMultY/2;
-        d = sqrtf(x*x+y*y);
-    }
-    else
-    {
-        float x = (v0.x - v1.x)/ windowSetting.fMultX;
-        float y = (v0.y - v1.y)/ windowSetting.fMultY;
-        d = sqrtf(x*x+y*y);
-    }
+    float x = g_vtxProjected5[0][0] / g_vtxProjected5[0][4] - g_vtxProjected5[1][0] / g_vtxProjected5[1][4];
+    float y = g_vtxProjected5[0][1] / g_vtxProjected5[0][4] - g_vtxProjected5[1][1] / g_vtxProjected5[1][4];
+
+    x = windowSetting.vpWidthW*x/windowSetting.fMultX/2;
+    y = windowSetting.vpHeightW*y/windowSetting.fMultY/2;
+    d = sqrtf(x*x+y*y);
 
     float s0 = v0.tcord[0].u * tex0.m_fTexWidth;
     float t0 = v0.tcord[0].v * tex0.m_fTexHeight;
@@ -848,27 +853,22 @@ void ComputeLOD(bool openGL)
 bool bHalfTxtScale=false;
 extern uint32 lastSetTile;
 
-void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture, bool openGL)
+void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture)
 {
     VTX_DUMP(TRACE2("Init vertex (%d) to vtx buf[%d]:", dwV, vtxIndex));
 
     TLITVERTEX &v = g_vtxBuffer[vtxIndex];
     VTX_DUMP(TRACE4("  Trans: x=%f, y=%f, z=%f, w=%f",  g_vtxTransformed[dwV].x,g_vtxTransformed[dwV].y,g_vtxTransformed[dwV].z,g_vtxTransformed[dwV].w));
-    if( openGL )
-    {
-        g_vtxProjected5[vtxIndex][0] = g_vtxTransformed[dwV].x;
-        g_vtxProjected5[vtxIndex][1] = g_vtxTransformed[dwV].y;
-        g_vtxProjected5[vtxIndex][2] = g_vtxTransformed[dwV].z;
-        g_vtxProjected5[vtxIndex][3] = g_vtxTransformed[dwV].w;
-        g_vtxProjected5[vtxIndex][4] = g_vecProjected[dwV].z;
 
-        if( g_vtxTransformed[dwV].w < 0 )
-            g_vtxProjected5[vtxIndex][4] = 0;
+    g_vtxProjected5[vtxIndex][0] = g_vtxTransformed[dwV].x;
+    g_vtxProjected5[vtxIndex][1] = g_vtxTransformed[dwV].y;
+    g_vtxProjected5[vtxIndex][2] = g_vtxTransformed[dwV].z;
+    g_vtxProjected5[vtxIndex][3] = g_vtxTransformed[dwV].w;
+    g_vtxProjected5[vtxIndex][4] = g_fFogCoord[dwV];
 
-        g_vtxIndex[vtxIndex] = vtxIndex;
-    }
+    g_vtxIndex[vtxIndex] = vtxIndex;
 
-    if( !openGL || options.bOGLVertexClipper == TRUE )
+    if( options.bOGLVertexClipper == TRUE )
     {
         v.x = g_vecProjected[dwV].x*gRSP.vtxXMul+gRSP.vtxXAdd;
         v.y = g_vecProjected[dwV].y*gRSP.vtxYMul+gRSP.vtxYAdd;
@@ -915,13 +915,10 @@ void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture, bool openGL)
         v.dcDiffuse = g_dwVtxDifColor[dwV];
     }
 
-    if( openGL )
-    {
-        g_oglVtxColors[vtxIndex][0] = v.r;
-        g_oglVtxColors[vtxIndex][1] = v.g;
-        g_oglVtxColors[vtxIndex][2] = v.b;
-        g_oglVtxColors[vtxIndex][3] = v.a;
-    }
+    g_oglVtxColors[vtxIndex][0] = v.r;
+    g_oglVtxColors[vtxIndex][1] = v.g;
+    g_oglVtxColors[vtxIndex][2] = v.b;
+    g_oglVtxColors[vtxIndex][3] = v.a;
 
     if( bTexture )
     {
@@ -989,7 +986,7 @@ void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture, bool openGL)
     {
         if( CRender::g_pRender->IsTexel1Enable() && CRender::g_pRender->m_pColorCombiner->m_pDecodedMux->isUsed(MUX_LODFRAC) )
         {
-            ComputeLOD(openGL);
+            ComputeLOD();
         }
         else
         {
@@ -1065,7 +1062,7 @@ uint32 LightVert(XVECTOR4 & norm, int vidx)
                 {
                     //float f = d2/gRSPlights[l].range*50;
                     float f = d2/15000*50;
-                    f = 1 - min(f,1);
+                    f = 1 - std::min(f,1.f);
                     fCosT *= f*f;
 
                     r += gRSPlights[l].fr * fCosT;
@@ -1524,28 +1521,16 @@ void ProcessVertexDataNoSSE(uint32 dwAddr, uint32 dwV0, uint32 dwNum)
 
 bool PrepareTriangle(uint32 dwV0, uint32 dwV1, uint32 dwV2)
 {
-    if( status.isVertexShaderEnabled || status.bUseHW_T_L )
-    {
-        g_vtxIndex[gRSP.numVertices++] = dwV0;
-        g_vtxIndex[gRSP.numVertices++] = dwV1;
-        g_vtxIndex[gRSP.numVertices++] = dwV2;
-        status.dwNumTrisRendered++;
-        gRSP.maxVertexID = max(gRSP.maxVertexID,max(dwV0,max(dwV1,dwV2)));
-    }
-    else
-    {
-        SP_Timing(SP_Each_Triangle);
+    SP_Timing(SP_Each_Triangle);
 
-        bool textureFlag = (CRender::g_pRender->IsTextureEnabled() || gRSP.ucode == 6 );
-        bool openGL = CDeviceBuilder::m_deviceGeneralType == OGL_DEVICE;
+    bool textureFlag = (CRender::g_pRender->IsTextureEnabled() || gRSP.ucode == 6 );
 
-        InitVertex(dwV0, gRSP.numVertices, textureFlag, openGL);
-        InitVertex(dwV1, gRSP.numVertices+1, textureFlag, openGL);
-        InitVertex(dwV2, gRSP.numVertices+2, textureFlag, openGL);
+    InitVertex(dwV0, gRSP.numVertices, textureFlag);
+    InitVertex(dwV1, gRSP.numVertices+1, textureFlag);
+    InitVertex(dwV2, gRSP.numVertices+2, textureFlag);
 
-        gRSP.numVertices += 3;
-        status.dwNumTrisRendered++;
-    }
+    gRSP.numVertices += 3;
+    status.dwNumTrisRendered++;
 
     return true;
 }
@@ -1558,8 +1543,6 @@ bool IsTriangleVisible(uint32 dwV0, uint32 dwV1, uint32 dwV2)
 {
     //return true;  //fix me
 
-    if( status.isVertexShaderEnabled || status.bUseHW_T_L ) return true;    // We won't have access to transformed vertex data
-
     DEBUGGER_ONLY_IF( (!debuggerEnableTestTris || !debuggerEnableCullFace), {return TRUE;});
     
 #ifdef DEBUGGER
@@ -2341,20 +2324,10 @@ void HackZ(std::vector<XVECTOR3>& points)
 
 void HackZAll()
 {
-    if( CDeviceBuilder::m_deviceGeneralType == DIRECTX_DEVICE )
+    for( uint32 i=0; i<gRSP.numVertices; i++)
     {
-        for( uint32 i=0; i<gRSP.numVertices; i++)
-        {
-            g_vtxBuffer[i].z = HackZ(g_vtxBuffer[i].z);
-        }
-    }
-    else
-    {
-        for( uint32 i=0; i<gRSP.numVertices; i++)
-        {
-            float w = g_vtxProjected5[i][3];
-            g_vtxProjected5[i][2] = HackZ(g_vtxProjected5[i][2]/w)*w;
-        }
+        float w = g_vtxProjected5[i][3];
+        g_vtxProjected5[i][2] = HackZ(g_vtxProjected5[i][2]/w)*w;
     }
 }
 
