@@ -20,10 +20,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef _RICE_RENDER_BASE_H
 #define _RICE_RENDER_BASE_H
 
-#include "osal_preproc.h"
 #include "Debugger.h"
 #include "RSP_Parser.h"
+#include "VectorMath.h"
 #include "Video.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
 
 /*
  *  Global variables defined in this file were moved out of Render class
@@ -234,7 +236,7 @@ extern ALIGN(16, RDP_Options gRDP)
 */
 void InitRenderBase();
 void SetFogMinMax(float fMin, float fMax, float fMul, float fOffset);
-void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture, bool openGL = true );
+void InitVertex(uint32 dwV, uint32 vtxIndex, bool bTexture);
 void InitVertexTextureConstants();
 bool PrepareTriangle(uint32 dwV0, uint32 dwV1, uint32 dwV2);
 bool IsTriangleVisible(uint32 dwV0, uint32 dwV1, uint32 dwV2);
