@@ -18,28 +18,31 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <vector>
 
-#include <stdarg.h>
-
+#include "CritSect.h"
+#include "RenderBase.h"
 #include "osal_opengl.h"
 
 #define M64P_PLUGIN_PROTOTYPES 1
-#include "m64p_types.h"
-#include "m64p_common.h"
-#include "m64p_plugin.h"
-#include "osal_dynamiclib.h"
-
 #include "Config.h"
 #include "Debugger.h"
 #include "DeviceBuilder.h"
 #include "FrameBuffer.h"
 #include "GraphicsContext.h"
-#include "Render.h"
 #include "RSP_Parser.h"
+#include "Render.h"
 #include "TextureFilters.h"
 #include "TextureManager.h"
 #include "Video.h"
+#include "m64p_common.h"
+#include "m64p_plugin.h"
+#include "m64p_types.h"
+#include "osal_dynamiclib.h"
 #include "version.h"
 
 //=======================================================
@@ -72,6 +75,7 @@ void (*renderCallback)(int) = NULL;
 /* definitions of pointers to Core config functions */
 ptr_ConfigOpenSection      ConfigOpenSection = NULL;
 ptr_ConfigSetParameter     ConfigSetParameter = NULL;
+ptr_ConfigSetParameterHelp ConfigSetParameterHelp = NULL;
 ptr_ConfigGetParameter     ConfigGetParameter = NULL;
 ptr_ConfigGetParameterHelp ConfigGetParameterHelp = NULL;
 ptr_ConfigSetDefaultInt    ConfigSetDefaultInt = NULL;
@@ -598,9 +602,18 @@ EXPORT m64p_error CALL PluginStartup(m64p_dynlib_handle CoreLibHandle, void *Con
         return M64ERR_INCOMPATIBLE;
     }
 
+    /* check Config API version to make sure ConfigSetParameterHelp is supported */
+    if (ConfigAPIVersion < 0x00020300)
+    {
+        DebugMessage(M64MSG_ERROR, "Emulator core Config API (v%i.%i.%i) is too old.  This plugin requires at least 2.3.0",
+                VERSION_PRINTF_SPLIT(ConfigAPIVersion));
+        return M64ERR_INCOMPATIBLE;
+    }
+
     /* Get the core config function pointers from the library handle */
     ConfigOpenSection = (ptr_ConfigOpenSection) osal_dynlib_getproc(CoreLibHandle, "ConfigOpenSection");
     ConfigSetParameter = (ptr_ConfigSetParameter) osal_dynlib_getproc(CoreLibHandle, "ConfigSetParameter");
+    ConfigSetParameterHelp = (ptr_ConfigSetParameterHelp) osal_dynlib_getproc(CoreLibHandle, "ConfigSetParameterHelp");
     ConfigGetParameter = (ptr_ConfigGetParameter) osal_dynlib_getproc(CoreLibHandle, "ConfigGetParameter");
     ConfigSetDefaultInt = (ptr_ConfigSetDefaultInt) osal_dynlib_getproc(CoreLibHandle, "ConfigSetDefaultInt");
     ConfigSetDefaultFloat = (ptr_ConfigSetDefaultFloat) osal_dynlib_getproc(CoreLibHandle, "ConfigSetDefaultFloat");
@@ -616,7 +629,7 @@ EXPORT m64p_error CALL PluginStartup(m64p_dynlib_handle CoreLibHandle, void *Con
     ConfigGetUserDataPath = (ptr_ConfigGetUserDataPath) osal_dynlib_getproc(CoreLibHandle, "ConfigGetUserDataPath");
     ConfigGetUserCachePath = (ptr_ConfigGetUserCachePath) osal_dynlib_getproc(CoreLibHandle, "ConfigGetUserCachePath");
 
-    if (!ConfigOpenSection || !ConfigSetParameter || !ConfigGetParameter ||
+    if (!ConfigOpenSection || !ConfigSetParameter || !ConfigSetParameterHelp || !ConfigGetParameter ||
         !ConfigSetDefaultInt || !ConfigSetDefaultFloat || !ConfigSetDefaultBool || !ConfigSetDefaultString ||
         !ConfigGetParamInt   || !ConfigGetParamFloat   || !ConfigGetParamBool   || !ConfigGetParamString ||
         !ConfigGetSharedDataFilepath || !ConfigGetUserConfigPath || !ConfigGetUserDataPath || !ConfigGetUserCachePath)
@@ -973,7 +986,7 @@ EXPORT void CALL ReadScreen2(void *dest, int *width, int *height, int bFront)
     if (dest == NULL)
         return;
 
-#if SDL_VIDEO_OPENGL
+#ifndef USE_GLES
     GLint oldMode;
     glGetIntegerv( GL_READ_BUFFER, &oldMode );
     if (bFront)
@@ -983,6 +996,28 @@ EXPORT void CALL ReadScreen2(void *dest, int *width, int *height, int bFront)
     glReadPixels( 0, 0, windowSetting.uDisplayWidth, windowSetting.uDisplayHeight,
                  GL_RGB, GL_UNSIGNED_BYTE, dest );
     glReadBuffer( oldMode );
+#else
+    unsigned char * line = (unsigned char *)dest;
+
+    unsigned char *frameBuffer = (unsigned char *)malloc((*width)*(*height)*4);
+
+    glReadPixels( 0, 0, windowSetting.uDisplayWidth, windowSetting.uDisplayHeight,
+                 GL_RGBA, GL_UNSIGNED_BYTE, frameBuffer );
+    //Convert RGBA to RGB
+    for (Uint32 y=0; y<windowSetting.uDisplayHeight; y++)
+    {
+        unsigned char *ptr = (unsigned char *) frameBuffer + (windowSetting.uDisplayWidth * 4 * y);
+        for (Uint32 x=0; x<windowSetting.uDisplayWidth; x++)
+        {
+            line[x*3] = ptr[0]; // red
+            line[x*3+1] = ptr[1]; // green
+            line[x*3+2] = ptr[2]; // blue
+            ptr += 4;
+        }
+        line += windowSetting.uDisplayWidth * 3;
+    }
+
+    free(frameBuffer);
 #endif
 }
     
