@@ -21,10 +21,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define _DLLINTERFACE_H_
 
 #define M64P_PLUGIN_PROTOTYPES 1
-#include "typedefs.h"
 #include "m64p_config.h"
 #include "m64p_plugin.h"
 #include "m64p_vidext.h"
+#include "osal_preproc.h"
+#include "typedefs.h"
 
 typedef struct {
     float   fViWidth, fViHeight;
@@ -124,12 +125,9 @@ typedef struct {
 
     bool    isMMXSupported;
     bool    isSSESupported;
-    bool    isVertexShaderSupported;
 
     bool    isMMXEnabled;
     bool    isSSEEnabled;
-    bool    isVertexShaderEnabled;
-    bool    bUseHW_T_L;                 // Use hardware T&L, for debug purpose only
 
     bool    toShowCFB;
 
@@ -168,6 +166,7 @@ extern ptr_ConfigOpenSection      ConfigOpenSection;
 extern ptr_ConfigListParameters   ConfigListParameters;
 extern ptr_ConfigSaveFile         ConfigSaveFile;
 extern ptr_ConfigSetParameter     ConfigSetParameter;
+extern ptr_ConfigSetParameterHelp ConfigSetParameterHelp;
 extern ptr_ConfigGetParameter     ConfigGetParameter;
 extern ptr_ConfigGetParameterHelp ConfigGetParameterHelp;
 extern ptr_ConfigSetDefaultInt    ConfigSetDefaultInt;
